import greenfoot.*;
import java.awt.Color;
import java.util.HashMap;
import java.util.Map;
public class Inventory extends Actor
{
    public static final int FONT_SIZE = 30;
    private Map<Class, Integer> inv = new HashMap<Class, Integer>();
    private boolean eDown = false;
    private boolean qDown = false;
    private int newBlockClassIndex = 0;
    private Class[] blockClasses = {Stone.class, Dirt.class, Wood.class};
    
    {
        for(Class cls : blockClasses) {
            inv.put(cls, 0);
        }
        updateImage();
    }
    
    public void act() {
        int prevIndex = newBlockClassIndex;
        if(Greenfoot.isKeyDown("e")) {
            if(!eDown) {
                newBlockClassIndex++;
                if(newBlockClassIndex >= blockClasses.length) {
                    newBlockClassIndex -= blockClasses.length;
                }
                eDown = true;
            }
        } else eDown = false;
        if(Greenfoot.isKeyDown("q")) {
            if(!qDown) {
                newBlockClassIndex--;
                if(newBlockClassIndex < 0) {
                    newBlockClassIndex += blockClasses.length;
                }
                qDown = true;
            }
        } else qDown = false;
        if(prevIndex != newBlockClassIndex) {
            updateImage();
        }
    }
    
    public Block getNewBlock() {
        Class newBlockClass = blockClasses[newBlockClassIndex];
        Integer quantity = inv.get(newBlockClass);
        if(quantity > 0) {
            inv.put(newBlockClass, quantity - 1);
            updateImage();
            try {
                return (Block)newBlockClass.newInstance();
            } catch(Exception e) {
                e.printStackTrace();
            }
        }
        return null;
    }
    
    public void addBlock(Class cls) {
        Integer quantity = inv.get(cls);
        if(quantity == null) return;
        inv.put(cls, quantity + 1);
        updateImage();
    }
    
    private void updateImage() {
        Class cls = blockClasses[newBlockClassIndex];
        setImage(new GreenfootImage("Adding: " + cls.getCanonicalName() + " (" + inv.get(cls) + ")", FONT_SIZE, Color.WHITE, null));
    }
}
